@@ -26,20 +26,17 @@ logger = logging.getLogger("pocketutils")
 
 class FigureSaver:
     """
-    Offers some small, specific extensions over matplotlib's ``figure.savefig``:
-    - can remove the figure from memory each iteration
-    - creates directories as needed
-    - can save a multi-figure PDF
-    - complains about issues
-    - can auto-fix some
-    - the ``FigureSaver.save`` function handles iterators of different types
+    Offers some small, specific extensions over matplotlib's ``figure.savefig``.
 
-    See ``FigureSaver.save`` for more info.
-    ``clear`` defines the behavior after saving a single figure:
-        - False    ==> do nothing
-        - True     ==> clear it
-        - callable ==> call it with the Figure instance
+    Specifically::
+        - can remove the figure from memory each iteration
+        - creates directories as needed
+        - can save a multi-figure PDF
+        - complains about issues
+        - can auto-fix some
+        - the ``FigureSaver.save`` function handles iterators of different types
 
+    See :meth:`save` for more info.
     """
 
     def __init__(
@@ -58,10 +55,11 @@ class FigureSaver:
 
         Args:
             save_under: A parent directory assumed for all saved figures
-            clear: Auto-close each figure after saving
+            clear: Auto-close each figure after saving (if a callable, call it)
             as_type: Force a specific filename suffix (e.g. ``as_type=".jpg")``
             check_paths: Check that paths are valid; without ``sanitize_paths``,
-                         raises an error if a path is invalid
+                         raises an error if a path is invalid;
+                         see :meth:`pocketutils.tools.path_tools.PathTools.sanitize_path`
             sanitize_paths: Try to sanitize paths (implies ``check_paths``)
             log: Call this function with a message indicating that a sanitized path differs
             kwargs: Passed to ``savefig``
@@ -71,20 +69,20 @@ class FigureSaver:
             raise TypeError(type(clear))
         self._clear = clear
         self._log = lambda _: None if log is None else log
-        self._as_type = "." + as_type.lstrip(".")
+        self._as_type = None if as_type is None else "." + as_type.lstrip(".")
         self._check_paths = check_paths
         self._sanitize_paths = sanitize_paths
         self._kwargs = {} if kwargs is None else kwargs
 
     def __mod__(self, tup):
         """
-        See: :meth:`save_one`.
+        See :meth:`save_one`.
         """
         self.save_one(*tup)
 
     def __idiv__(self, tup):
         """
-        See: :meth:`save`.
+        See :meth:`save`.
         """
         self.save(*tup)
 
@@ -210,21 +208,25 @@ class FigureSaver:
             pass
             figure.clear()
             figure.clf()
+            plt.close(figure)
         elif callable(self._clear):
             self._clear(figure)
 
     def _sanitized_file(self, path: PathLike, overwrite: bool) -> Path:
         """
-        Sanitizes a file path:
+        Sanitizes a file path.
+
+        Specifically:
             - prepends self._save_under if needed
             - warns about issues
 
         Args:
             path: The path, including directory, but excluding self._save_under
+            overwrite: Overwrite the file
         """
         path = Path(path)
         if self._check_paths or self._sanitize_paths:
-            new_path = PathTools.sanitize_path(path, show_warnings=False)
+            new_path = PathTools.sanitize_path(path, warn=False)
             if new_path != path and self._sanitize_paths:
                 self._log(f"Sanitized filename {path} → {new_path}")
             elif new_path != path:
